@@ -1,7 +1,7 @@
 /*
  ex: set tabstop=4 shiftwidth=4 autoindent:
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU Lesser General Public              |
@@ -65,16 +65,22 @@ int ping_host(host_t *host, ping_t *ping) {
 		}
 
 		if (!strstr(host->hostname, "localhost")) {
-			if (host->ping_method == PING_ICMP) {
-				ping_result = ping_icmp(host, ping);
-			} else if (host->ping_method == PING_UDP) {
-				ping_result = ping_udp(host, ping);
-			} else if (host->ping_method == PING_TCP) {
-				ping_result = ping_tcp(host, ping);
+			if (get_address_type(host) == 1) {
+				if (host->ping_method == PING_ICMP) {
+					ping_result = ping_icmp(host, ping);
+				} else if (host->ping_method == PING_UDP) {
+					ping_result = ping_udp(host, ping);
+				} else if (host->ping_method == PING_TCP) {
+					ping_result = ping_tcp(host, ping);
+				}
+			} else if (host->availability_method == AVAIL_PING) {
+				snprintf(ping->ping_status, 50, "0.000");
+				snprintf(ping->ping_response, SMALL_BUFSIZE, "PING: Device is Unknown or is IPV6.  Please use the SNMP ping options only.");
+				return HOST_DOWN;
 			}
 		} else {
 			snprintf(ping->ping_status, 50, "0.000");
-			snprintf(ping->ping_response, SMALL_BUFSIZE, "PING: Device does not require ping");
+			snprintf(ping->ping_response, SMALL_BUFSIZE, "PING: Device does not require ping.");
 			ping_result = HOST_UP;
 		}
 	}
@@ -318,6 +324,7 @@ int ping_icmp(host_t *host, ping_t *ping) {
 			break;
 		}
 	}
+
 	#if !(defined(__CYGWIN__) && !defined(SOLAR_PRIV))
 	if (hasCaps() != TRUE) {
 		if (seteuid(getuid()) == -1) {
@@ -383,6 +390,12 @@ int ping_icmp(host_t *host, ping_t *ping) {
 					return HOST_DOWN;
 				}
 
+				if (is_debug_device(host->id)) {
+					SPINE_LOG(("Device[%i] DEBUG: Attempting to ping %s, seq %d (Retry %d of %d)", host->id, new_hostname, icmp->icmp_seq, retry_count, host->ping_retries));
+				} else {
+					SPINE_LOG_DEBUG(("Device[%i] DEBUG: Attempting to ping %s, seq %d (Retry %d of %d)", host->id, new_hostname, icmp->icmp_seq, retry_count, host->ping_retries));
+				}
+
 				/* decrement the timeout value by the total time */
 				timeout.tv_sec  = rint((host_timeout - total_time) / 1000);
 				timeout.tv_usec = ((int) (host_timeout - total_time) % 1000) * 1000;
@@ -835,6 +848,63 @@ int ping_tcp(host_t *host, ping_t *ping) {
 	}
 }
 
+/*! \fn int get_address_type(host_t *host)
+ *  \brief determines using getaddrinfo the iptype and returns the iptype
+ *
+ *  \return 1 - IPv4, 2 - IPv6, 0 - Unknown
+ */
+int get_address_type(host_t *host) {
+	struct addrinfo hints, *res, *res_list;
+	char addrstr[255];
+	void *ptr;
+	int addr_found = FALSE;
+
+	memset(&hints, 0, sizeof(hints));
+
+	hints.ai_family   = AF_UNSPEC;
+	hints.ai_socktype = SOCK_DGRAM;
+	hints.ai_flags    = AI_CANONNAME | AI_ADDRCONFIG;
+	int error;
+
+	if ((error = getaddrinfo(host->hostname, NULL, &hints, &res_list)) != 0) {
+		SPINE_LOG(("WARNING: Unable to determine address info for %s (%s)", host->hostname, gai_strerror(error)));
+		return SPINE_NONE;
+	}
+
+	for (res = res_list; res != NULL; res = res->ai_next) {
+		inet_ntop(res->ai_family, res->ai_addr->sa_data, addrstr, 100);
+
+		switch(res->ai_family) {
+			case AF_INET:
+				ptr = &((struct sockaddr_in *) res->ai_addr)->sin_addr;
+				addr_found = TRUE;
+				break;
+			case AF_INET6:
+				ptr = &((struct sockaddr_in6 *) res->ai_addr)->sin6_addr;
+				addr_found = TRUE;
+				break;
+		}
+
+		inet_ntop(res->ai_family, ptr, addrstr, 100);
+
+		SPINE_LOG_HIGH(("Device[%d] IPv%d address %s (%s)\n", host->id, res->ai_family == PF_INET6 ? 6:4, addrstr, res->ai_canonname));
+
+		if (res->ai_family != PF_INET6) {
+			freeaddrinfo(res_list);
+
+			return SPINE_IPV4;
+		}
+	}
+
+	freeaddrinfo(res_list);
+
+	if (addr_found) {
+		return SPINE_IPV6;
+	} else {
+		return SPINE_NONE;
+	}
+}
+
 /*! \fn int init_sockaddr(struct sockaddr_in *name, const char *hostname, unsigned short int port)
  *  \brief converts a hostname to an internet address
  *
@@ -842,141 +912,82 @@ int ping_tcp(host_t *host, ping_t *ping) {
  *
  */
 int init_sockaddr(struct sockaddr_in *name, const char *hostname, unsigned short int port) {
-	struct hostent *hostinfo;
-	int retry_count;
-	#if !defined(H_ERRNO_DECLARED) && !defined(_AIX)
-	extern int h_errno;
-	#endif
+	struct addrinfo hints, *hostinfo, *p;
+	int rv, retry_count;
 
-	name->sin_family = AF_INET;
-	name->sin_port   = htons (port);
+	// Initialize the hints structure
+	memset(&hints, 0, sizeof hints);
 
+	hints.ai_family = AF_INET;
+	hints.ai_flags = AI_CANONNAME | AI_ADDRCONFIG;
 	retry_count = 0;
+	rv = 0;
 
-	#ifdef HAVE_THREADSAFE_GETHOSTBYNAME
-	retry:
-	hostinfo = gethostbyname(hostname);
+	while (TRUE) {
+		rv = getaddrinfo(hostname, NULL, &hints, &hostinfo);
 
-	if (!hostinfo) {
-		if (h_errno == TRY_AGAIN && retry_count < 3) {
-			retry_count++;
-			usleep(50000);
-			goto retry;
-		} else {
-			return NULL;
-		}
-	} else {
-		name->sin_addr = *(struct in_addr *) hostinfo->h_addr;
-	}
-
-	#else
-	#ifdef HAVE_GETHOSTBYNAME_R_GLIBC
-	struct hostent result_buf;
-	size_t len = 1024;
-	char   *buf;
-	int    herr;
-	int    rv;
-
-	buf = malloc(len*sizeof(char));
-	memset(buf, 0, len*sizeof(char));
-
-	while (1) {
-		rv = gethostbyname_r(hostname, &result_buf, buf, len,
-		&hostinfo, &herr);
-
-		if (!hostinfo) {
-			if (rv == ERANGE) {
-				len *= 2;
-				buf = realloc(buf, len*sizeof(char));
-
-				continue;
-			} else if (herr == TRY_AGAIN && retry_count < 3) {
-				retry_count++;
-				usleep(50000);
-				continue;
-			} else {
-				free(buf);
-				return FALSE;
-			}
-		} else {
+		if (rv == 0) {
 			break;
-		}
-	}
+		} else {
+			switch (rv) {
+				case EAI_AGAIN:
+					if (retry_count < 3) {
+						SPINE_LOG(("WARNING: EAGAIN received resolving after 3 retryies for host %s (%s)", hostname, gai_strerror(rv)));
+						if (hostinfo != NULL) {
+							freeaddrinfo(hostinfo);
+						}
 
-	name->sin_addr = *(struct in_addr *) hostinfo->h_addr;
+						retry_count++;
+						usleep(50000);
+						continue;
+					} else {
+						SPINE_LOG(("WARNING: Error resolving after 3 retryies for host %s (%s)", hostname, gai_strerror(rv)));
+						if (hostinfo != NULL) {
+							freeaddrinfo(hostinfo);
+						}
+						return FALSE;
+					}
 
-	free(buf);
-	#else
-	#ifdef HAVE_GETHOSTBYNAME_R_SOLARIS
-	size_t  len = 8192;
-	char   *buf = NULL;
-	struct hostent result;
+					break;
+				case EAI_FAIL:
+					SPINE_LOG(("WARNING: DNS Server reported permanent error for host %s (%s)", hostname, gai_strerror(rv)));
+					if (hostinfo != NULL) {
+						freeaddrinfo(hostinfo);
+					}
+					return FALSE;
 
-	buf = malloc(len*sizeof(char));
-	memset(buf, 0, sizeof(buf));
+					break;
+				case EAI_MEMORY:
+					SPINE_LOG(("WARNING: Out of memory trying to resolve host %s (%s)", hostname, gai_strerror(rv)));
+					if (hostinfo != NULL) {
+						freeaddrinfo(hostinfo);
+					}
+					return FALSE;
 
-	while (1) {
-		hostinfo = gethostbyname_r(hostname, &result, buf, len, &h_errno);
-		if (!hostinfo) {
-			if (errno == ERANGE) {
-				len += 1024;
-				buf = realloc(buf, len*sizeof(char));
-				memset(buf, 0, sizeof(buf));
+					break;
+				default:
+					SPINE_LOG(("WARNING: Unknown error while resolving host %s (%s)", hostname, gai_strerror(rv)));
+					if (hostinfo != NULL) {
+						freeaddrinfo(hostinfo);
+					}
+					return FALSE;
 
-				continue;
-			} else if (h_errno == TRY_AGAIN && retry_count < 3) {
-				retry_count++;
-				usleep(50000);
-				continue;
-			} else {
-				free(buf);
-				return NULL;
+					break;
 			}
-		} else {
-			break;
 		}
 	}
 
-	name->sin_addr = *(struct in_addr *) hostinfo->h_addr;
-
-	free(buf);
-	#else
-	#ifdef HAVE_GETHOSTBYNAME_R_HPUX
-	struct hostent hostent;
-	struct hostent_data buf;
-	int rv;
-
-	rv = gethostbyname_r(hostname, &hostent, &buf);
-	if (!rv) {
-		name->sin_addr = *(struct in_addr *) hostent->h_addr;
-	}
-
-	#else
-	retry:
-	thread_mutex_lock(LOCK_GHBN);
-	hostinfo = gethostbyname(hostname);
-	if (!hostinfo) {
-		thread_mutex_unlock(LOCK_GHBN);
-		if (h_errno == TRY_AGAIN && retry_count < 3) {
-			retry_count++;
-			usleep(50000);
-			goto retry;
-		} else {
-			hostinfo = NULL;
-		}
-	} else {
-		name->sin_addr = *(struct in_addr *) hostinfo->h_addr;
-		thread_mutex_unlock(LOCK_GHBN);
-	}
-	#endif
-	#endif
-	#endif
-	#endif
-
 	if (hostinfo == NULL) {
 		SPINE_LOG(("WARNING: Unknown host %s", hostname));
 		return FALSE;
 	} else {
+		// Copy socket details
+		name->sin_family = hostinfo->ai_family;
+		name->sin_addr = ((struct sockaddr_in *)hostinfo->ai_addr)->sin_addr;
+		name->sin_port = htons(port);
+
+		// Free results var
+		freeaddrinfo(hostinfo);
 		return TRUE;
 	}
 }
